==> cueplot-0.0.5.tar.gz: cueplot-0.0.5/src/gui/opt/terminal/TerminalPostScriptOptionWidget.h <==
/*
 * Cueplot: a GUI front-end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef TERMINAL_POST_SCRIPT_OPTION_WIDGET_INCLUDED
#define TERMINAL_POST_SCRIPT_OPTION_WIDGET_INCLUDED

#include "OptionWidget.h"

class TerminalPostScript;

class QCheckBox;
class QComboBox;
class QLineEdit;
class QSpinBox;

//! set terminal postscript のオプションを扱うウィジェット
class TerminalPostScriptOptionWidget : public OptionWidget
{
	Q_OBJECT

	public:
		explicit TerminalPostScriptOptionWidget(QWidget *parent = 0);
		~TerminalPostScriptOptionWidget();

		void construct();

	private:
		// don't implement these
		TerminalPostScriptOptionWidget(const TerminalPostScriptOptionWidget &);
		TerminalPostScriptOptionWidget &operator=(const TerminalPostScriptOptionWidget &);

		void init();
		void apply();
		void setWidget();
		TerminalPostScript *terminalPostScript;
		QComboBox *modeComboBox;
		QComboBox *colorComboBox;
		QComboBox *solidComboBox;
		QLineEdit *fontNameLineEdit;
		QSpinBox *fontSizeSpinBox;
		QCheckBox *enhancedCheckBox;
};
#endif // TERMINAL_POST_SCRIPT_OPTION_WIDGET_INCLUDED

==> cueplot-0.0.6.tar.gz: cueplot-0.0.6/src/gui/opt/terminal/TerminalPostScriptOptionWidget.h <==
/*
 * Cueplot: a GUI front-end to gnuplot
 * Copyright (C) 2007, 2008 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef TERMINAL_POST_SCRIPT_OPTION_WIDGET_INCLUDED
#define TERMINAL_POST_SCRIPT_OPTION_WIDGET_INCLUDED

#include "OptionWidget.h"

class TerminalPostScript;

class QCheckBox;
class QComboBox;
class QLineEdit;
class QSpinBox;

//! set terminal postscript のオプションを扱うウィジェット
class TerminalPostScriptOptionWidget : public OptionWidget
{
	Q_OBJECT

	public:
		explicit TerminalPostScriptOptionWidget(QWidget *parent = 0);
		~TerminalPostScriptOptionWidget();

		void construct();

	private:
		// don't implement these
		TerminalPostScriptOptionWidget(const TerminalPostScriptOptionWidget &);
		TerminalPostScriptOptionWidget &operator=(const 
				TerminalPostScriptOptionWidget &);

		void init();
		void apply();
		void setWidget();
		TerminalPostScript *terminalPostScript;
		QComboBox *modeComboBox;
		QComboBox *colorComboBox;
		QComboBox *solidComboBox;
		QLineEdit *fontNameLineEdit;
		QSpinBox *fontSizeSpinBox;
		QCheckBox *enhancedCheckBox;
};
#endif // TERMINAL_POST_SCRIPT_OPTION_WIDGET_INCLUDED
